Crate specmc_base

source ·
A library with common code for parsing Minecraft specification files.

Modules

  • Module for parsing tokens.
  • Module for tokenizing strings.

Macros

  • Ensure that the given condition is true, otherwise return the given value.
  • Ensure that the next tokens in the list match the given tokens. This will remove the tokens from the list. Tokens are checked in reverse order.