Module specmc_base::parse
source · Expand description
Module for parsing tokens.
Structs
- An identifier. The identifier must not be empty and can only contain letters, numbers, and underscores. The identifier must not start with a number.
Enums
- A literal value. This can be a boolean, integer, float, or string.