Parse

Trait Parse 

pub trait Parse
where Self: Sized,
{ // Required method fn parse(tokens: &mut Vec<String>) -> Result<Self, ParseError>; }

Required Methods

fn parse(tokens: &mut Vec<String>) -> Result<Self, ParseError>

Parse a list of tokens into an object, consuming the tokens as needed. The token list is consumed in reverse order. If this fails, it is not guaranteed that no tokens have been consumed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors